==> bucketlib-fabric-1.21.3-4.2.4.0-sources.jar: de/cech12/bucketlib/client/model/UniversalBucketBakedModel.java <==
package de.cech12.bucketlib.client.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_5819;
import net.minecraft.class_777;
import net.minecraft.class_806;
import net.minecraft.class_809;
import java.util.List;

public class UniversalBucketBakedModel implements class_1087 {

    private final List<class_777> bakedQuads;
    private final class_809 itemTransforms;
    private final class_806 overrides;
    private final class_1058 particleSprite;

    public UniversalBucketBakedModel(List<class_777> bakedQuads, class_809 itemTransforms, class_806 overrides, class_1058 particleSprite) {
        this.bakedQuads = bakedQuads;
        this.itemTransforms = itemTransforms;
        this.overrides = overrides;
        this.particleSprite = particleSprite;
    }

    @Nonnull
    @Override
    public List<class_777> method_4707(@Nullable class_2680 blockState, @Nullable class_2350 direction, @Nonnull class_5819 randomSource) {
        return this.bakedQuads;
    }

    @Override
    public boolean method_4708() {
        return false;
    }

    @Override
    public boolean method_4712() {
        return false;
    }

    @Override
    public boolean method_24304() {
        return false;
    }

    @Override
    public boolean method_4713() {
        return false;
    }

    @Nonnull
    @Override
    public class_1058 method_4711() {
        return this.particleSprite;
    }

    @Nonnull
    @Override
    public class_809 method_4709() {
        return this.itemTransforms;
    }

    @Nonnull
    @Override
    public class_806 method_4710() {
        return overrides;
    }

}

==> bucketlib-fabric-1.21-4.1.6.0-sources.jar: de/cech12/bucketlib/client/model/UniversalBucketBakedModel.java <==
package de.cech12.bucketlib.client.model;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import net.minecraft.class_1058;
import net.minecraft.class_1087;
import net.minecraft.class_2350;
import net.minecraft.class_2680;
import net.minecraft.class_5819;
import net.minecraft.class_777;
import net.minecraft.class_806;
import net.minecraft.class_809;
import java.util.List;

public class UniversalBucketBakedModel implements class_1087 {

    private final List<class_777> bakedQuads;
    private final class_809 itemTransforms;
    private final class_806 itemOverrides;
    private final class_1058 particleSprite;

    public UniversalBucketBakedModel(List<class_777> bakedQuads, class_809 itemTransforms, class_806 itemOverrides, class_1058 particleSprite) {
        this.bakedQuads = bakedQuads;
        this.itemTransforms = itemTransforms;
        this.itemOverrides = itemOverrides;
        this.particleSprite = particleSprite;
    }

    @Nonnull
    @Override
    public List<class_777> method_4707(@Nullable class_2680 blockState, @Nullable class_2350 direction, @Nonnull class_5819 randomSource) {
        return this.bakedQuads;
    }

    @Override
    public boolean method_4708() {
        return false;
    }

    @Override
    public boolean method_4712() {
        return false;
    }

    @Override
    public boolean method_24304() {
        return false;
    }

    @Override
    public boolean method_4713() {
        return false;
    }

    @Nonnull
    @Override
    public class_1058 method_4711() {
        return this.particleSprite;
    }

    @Nonnull
    @Override
    public class_809 method_4709() {
        return this.itemTransforms;
    }

    @Nonnull
    @Override
    public class_806 method_4710() {
        return this.itemOverrides;
    }

}
